@@ -23,14 +23,3 @@ class StatType(Enum):
 
     def __repr__(self) -> str:
         return self.value()
-
-
-def main() -> None:
-    print(dir(StatType))
-    print(dir(StatType.BOUGHT))
-    print(StatType.to_enum("bOUGHt"))
-    print(StatType.BOUGHT.value())
-
-
-if __name__ == "__main__":
-    main()
